{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Filter single sample sv vcf from paired read callers(Manta/Smoove)",
            "inputs": [
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "id": "#main/abundance_percentage"
                },
                {
                    "type": "File",
                    "id": "#main/bam"
                },
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "id": "#main/deletion_depth"
                },
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "id": "#main/duplication_depth"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#main/output_vcf_name"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/snps_vcf"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/sv_paired_count"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/sv_split_count"
                },
                {
                    "type": "File",
                    "id": "#main/sv_vcf"
                },
                {
                    "type": [
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/vcf_source/manta",
                                "#main/vcf_source/smoove"
                            ]
                        }
                    ],
                    "id": "#main/vcf_source"
                }
            ],
            "steps": [
                {
                    "run": "#filter_sv_vcf_depth.cwl",
                    "in": [
                        {
                            "source": "#main/deletion_depth",
                            "id": "#main/depth_filter/deletion_depth"
                        },
                        {
                            "source": "#main/duplication_depth",
                            "id": "#main/depth_filter/duplication_depth"
                        },
                        {
                            "source": "#main/duphold_annotate/annotated_sv_vcf",
                            "id": "#main/depth_filter/input_vcf"
                        },
                        {
                            "source": "#main/output_vcf_name",
                            "id": "#main/depth_filter/output_vcf_name"
                        },
                        {
                            "default": "duphold",
                            "id": "#main/depth_filter/vcf_source"
                        }
                    ],
                    "out": [
                        "#main/depth_filter/filtered_sv_vcf"
                    ],
                    "id": "#main/depth_filter"
                },
                {
                    "run": "#duphold.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/duphold_annotate/bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/duphold_annotate/reference"
                        },
                        {
                            "source": "#main/snps_vcf",
                            "id": "#main/duphold_annotate/snps_vcf"
                        },
                        {
                            "source": "#main/read_support_filter/filtered_sv_vcf",
                            "id": "#main/duphold_annotate/sv_vcf"
                        }
                    ],
                    "out": [
                        "#main/duphold_annotate/annotated_sv_vcf"
                    ],
                    "id": "#main/duphold_annotate"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#main/depth_filter/filtered_sv_vcf",
                            "id": "#main/filtered_vcf_bgzip/file"
                        }
                    ],
                    "out": [
                        "#main/filtered_vcf_bgzip/bgzipped_file"
                    ],
                    "id": "#main/filtered_vcf_bgzip"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/filtered_vcf_bgzip/bgzipped_file",
                            "id": "#main/filtered_vcf_index/vcf"
                        }
                    ],
                    "out": [
                        "#main/filtered_vcf_index/indexed_vcf"
                    ],
                    "id": "#main/filtered_vcf_index"
                },
                {
                    "run": "#filter_sv_vcf_read_support.cwl",
                    "in": [
                        {
                            "source": "#main/abundance_percentage",
                            "id": "#main/read_support_filter/abundance_percentage"
                        },
                        {
                            "source": "#main/sv_vcf",
                            "id": "#main/read_support_filter/input_vcf"
                        },
                        {
                            "source": "#main/sv_paired_count",
                            "id": "#main/read_support_filter/paired_count"
                        },
                        {
                            "source": "#main/sv_split_count",
                            "id": "#main/read_support_filter/split_count"
                        },
                        {
                            "source": "#main/vcf_source",
                            "id": "#main/read_support_filter/vcf_source"
                        }
                    ],
                    "out": [
                        "#main/read_support_filter/filtered_sv_vcf"
                    ],
                    "id": "#main/read_support_filter"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/filtered_vcf_index/indexed_vcf",
                    "id": "#main/filtered_vcf"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "bgzip VCF",
            "baseCommand": [
                "/opt/htslib/bin/bgzip"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "$(inputs.file.basename).gz",
            "arguments": [
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bgzip.cwl/file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bgzip.cwl/bgzipped_file",
                    "outputBinding": {
                        "glob": "$(inputs.file.basename).gz"
                    }
                }
            ],
            "id": "#bgzip.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": "/usr/bin/duphold",
            "arguments": [
                "--threads",
                "$(runtime.cores)"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 10000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/duphold-cwl:0.1.5"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--bam"
                    },
                    "doc": "aligned bam/cram file",
                    "id": "#duphold.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "duphold_annotated.vcf",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--output"
                    },
                    "doc": "output vcf file name",
                    "id": "#duphold.cwl/output_vcf_name"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--fasta"
                    },
                    "doc": "reference used to align bam",
                    "id": "#duphold.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--snp"
                    },
                    "doc": "snps vcf file to annotate hom/het variant counts within sv",
                    "id": "#duphold.cwl/snps_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--vcf"
                    },
                    "doc": "sv vcf file to annotate",
                    "id": "#duphold.cwl/sv_vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_name)"
                    },
                    "id": "#duphold.cwl/annotated_sv_vcf"
                }
            ],
            "id": "#duphold.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/bin/bash",
                "filter_sv_vcf_depth.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bcftools-cwl:1.9"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "filter_sv_vcf_depth.sh",
                            "entry": "#!/bin/bash\nset -eou pipefail\n\nINPUT_VCF=\"$1\"\nOUTPUT_VCF=\"$2\"\nDEL_DEPTH=\"$3\"\nDUP_DEPTH=\"$4\"\nVCF_SOURCE=\"$5\"\n\nif [ \"$VCF_SOURCE\" == \"cnvnator\" ]; then\n  echo \"Running filter for cnvnator vcf\"\n  filter_expression=\"(natorRD>$DUP_DEPTH | natorRD<$DEL_DEPTH)\"\nelif [ \"$VCF_SOURCE\" ==  \"cnvkit\" ]; then\n  echo \"Running filter for cnvkit vcf\"\n  filter_expression=\"(FOLD_CHANGE>$DUP_DEPTH | FOLD_CHANGE<$DEL_DEPTH)\"\nelif [ \"$VCF_SOURCE\" ==  \"duphold\" ]; then\n  echo \"Running filter for vcf annotated by duphold\"\n  filter_expression=\"((SVTYPE='DEL' & FMT/DHFFC[0] < $DEL_DEPTH) | (SVTYPE='DUP' & FMT/DHBFC[0] > $DUP_DEPTH) | SVTYPE='BND' | SVTYPE='INS' | SVTYPE='INV')\"\nelse\n  echo \"vcf source: '$VCF_SOURCE' is not supported for SV filtering\"\n  exit 1\nfi\n/opt/bcftools/bin/bcftools filter \"$INPUT_VCF\" -o \"$OUTPUT_VCF\" -i \"$filter_expression\"\n"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "default": 0.75,
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "Depth for deletions must be less than this cutoff to pass the filter.",
                    "id": "#filter_sv_vcf_depth.cwl/deletion_depth"
                },
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "default": 1.25,
                    "inputBinding": {
                        "position": 4
                    },
                    "doc": "Depth for duplications must be greater than this cutoff to pass the filter.",
                    "id": "#filter_sv_vcf_depth.cwl/duplication_depth"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "vcf file to filter",
                    "id": "#filter_sv_vcf_depth.cwl/input_vcf"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "filtered_cnv.vcf",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "output vcf file name",
                    "id": "#filter_sv_vcf_depth.cwl/output_vcf_name"
                },
                {
                    "type": [
                        {
                            "type": "enum",
                            "symbols": [
                                "#filter_sv_vcf_depth.cwl/vcf_source/cnvnator",
                                "#filter_sv_vcf_depth.cwl/vcf_source/cnvkit",
                                "#filter_sv_vcf_depth.cwl/vcf_source/duphold"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "source caller of the vcf input file",
                    "id": "#filter_sv_vcf_depth.cwl/vcf_source"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_name)"
                    },
                    "id": "#filter_sv_vcf_depth.cwl/filtered_sv_vcf"
                }
            ],
            "id": "#filter_sv_vcf_depth.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/bin/bash",
                "filter_sv_vcf_read_support.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bcftools-cwl:1.9"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "filter_sv_vcf_read_support.sh",
                            "entry": "#!/bin/bash\nset -eou pipefail\n\nabundance=\"$1\"\ninput_vcf=\"$2\"\noutput_vcf=\"$3\"\npaired_count=\"$4\"\nsplit_count=\"$5\"\nvcf_source=\"$6\"\n\nif [ \"$vcf_source\" == \"smoove\" ]; then\n  echo \"Running filter for smoove vcf\"\n  filter_expression=\"((AS >= $split_count) && (AP >= $paired_count) && ((AP+AS) / (AP+RP+AS+RS) >= $abundance))\"\nelif [ \"$vcf_source\" ==  \"manta\" ]; then\n  echo \"Running filter for manta vcf\"\n  filter_expression=\"((SR[0:*]=\\\".\\\" || (SR[0:1] >= $split_count)) && (PR[0:1] >= $paired_count) && ((SR[0:*]=\\\".\\\" && (PR[0:1] / (PR[0:0]+PR[0:1]) >= $abundance))|| ((SR[0:1]+PR[0:1]) / (SR[0:0]+SR[0:1]+PR[0:1]+PR[0:0]) >= $abundance)))\"\nelse\n  echo \"vcf source: '$vcf_source' is not supported for SV filtering\"\n  exit 1\nfi\n\n/opt/bcftools/bin/bcftools filter \"$input_vcf\" -o \"$output_vcf\" -i \"$filter_expression\"\n"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "double"
                    ],
                    "default": 0.1,
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "required alternate read abundance percentage to pass",
                    "id": "#filter_sv_vcf_read_support.cwl/abundance_percentage"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "vcf file to filter",
                    "id": "#filter_sv_vcf_read_support.cwl/input_vcf"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "filtered_sv.vcf",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "output vcf file name",
                    "id": "#filter_sv_vcf_read_support.cwl/output_vcf_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "inputBinding": {
                        "position": 4
                    },
                    "doc": "number of alternate paired reads support needed to pass",
                    "id": "#filter_sv_vcf_read_support.cwl/paired_count"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "if present in variant, number of alternate split reads support needed to pass",
                    "id": "#filter_sv_vcf_read_support.cwl/split_count"
                },
                {
                    "type": [
                        {
                            "type": "enum",
                            "symbols": [
                                "#filter_sv_vcf_read_support.cwl/vcf_source/manta",
                                "#filter_sv_vcf_read_support.cwl/vcf_source/smoove"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 6
                    },
                    "doc": "source caller of the vcf input file",
                    "id": "#filter_sv_vcf_read_support.cwl/vcf_source"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_name)"
                    },
                    "id": "#filter_sv_vcf_read_support.cwl/filtered_sv_vcf"
                }
            ],
            "id": "#filter_sv_vcf_read_support.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "arguments": [
                "cp",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)/$(inputs.vcf.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/bin/tabix",
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index_vcf.cwl/indexed_vcf"
                }
            ],
            "id": "#index_vcf.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
